Read-only OpenAI-compatible remote MCP transport. Read-only OpenAI-compatible MCP transport for the WebMCP listener.
The remote surface deliberately shares the RuntimeAdapter read boundary
with the browser bridge, but it has an independent authentication and Origin
policy. A TLS-terminating reverse proxy is expected to validate the external
OAuth bearer token and inject the configured internal bearer token.
Structs
- Fetch
Input - Input accepted by the OpenAI-compatible
fetchtool. - Fetch
Output - The structured result returned by
fetch. - Remote
McpEndpoint - Remote MCP HTTP endpoint collection mounted by
crate::WebmcpServer. - Remote
McpHandler - Read-only MCP handler backed by a WebMCP runtime adapter.
- Remote
McpServer Config - Runtime configuration for the remote MCP transport.
- Search
Input - Input accepted by the OpenAI-compatible
searchtool. - Search
Output - The structured result returned by
search. - Search
Result - A search result compatible with the OpenAI remote MCP contract.