Authenticated WebMCP bridge primitives for VT Code.
The crate separates transport, pairing, workspace policy, and runtime
integration. This lets the interactive TUI provide an adapter that routes
through its existing permission pipeline while the standalone command uses
FilesystemWorkspace.
Re-exports
pub use error::Result;pub use error::WebmcpError;pub use event_hub::EventHubConfig;pub use event_hub::EventHubSubscription;pub use event_hub::SequencedThreadEvent;pub use event_hub::WebmcpEventHub;pub use filesystem::FilesystemLimits;pub use filesystem::FilesystemWorkspace;pub use pairing::PairingDisplay;pub use pairing::PairingManager;pub use pairing::PairingSession;pub use protocol::BridgeRequest;pub use protocol::BridgeResponse;pub use protocol::BridgeSettings;pub use protocol::FileChange;pub use protocol::PROTOCOL_VERSION;pub use remote_mcp::FetchInput;pub use remote_mcp::FetchOutput;pub use remote_mcp::RemoteMcpEndpoint;pub use remote_mcp::RemoteMcpHandler;pub use remote_mcp::RemoteMcpServerConfig;pub use remote_mcp::SearchInput;pub use remote_mcp::SearchOutput;pub use remote_mcp::SearchResult;pub use runtime::RuntimeAdapter;pub use runtime::RuntimeStatus;pub use server::WebmcpServer;pub use server::WebmcpServerConfig;
Modules
- error
- Error types shared by the bridge and adapters.
- event_
hub - Bounded canonical runtime event replay and subscription hub.
- filesystem
- Safe headless filesystem runtime adapter.
- pairing
- One-time pairing and revocation state.
- protocol
- Browser/server WebSocket protocol types.
- remote_
mcp - Read-only OpenAI-compatible remote MCP transport. Read-only OpenAI-compatible MCP transport for the WebMCP listener.
- runtime
- Runtime adapter traits and bridge result types.
- server
- Axum WebSocket server and request dispatcher.